@@ -1,6 +1,6 @@
 import sys
 
-from je_auto_control.utils.exception.exception_tag import windows_import_error
+from je_auto_control.utils.exception.exception_tags import windows_import_error
 from je_auto_control.utils.exception.exceptions import AutoControlException
 
 if sys.platform not in ["win32", "cygwin", "msys"]:
