@@ -1,30 +1,30 @@
 import sys
 from typing import Tuple
 
-from je_auto_control.utils.exception.exception_tag import keyboard_hotkey
-from je_auto_control.utils.exception.exception_tag import keyboard_press_key
-from je_auto_control.utils.exception.exception_tag import keyboard_release_key
-from je_auto_control.utils.exception.exception_tag import keyboard_type_key
-from je_auto_control.utils.exception.exception_tag import keyboard_write
-from je_auto_control.utils.exception.exception_tag import keyboard_write_cant_find
-from je_auto_control.utils.exception.exception_tag import table_cant_find_key
+from je_auto_control.utils.exception.exception_tags import keyboard_hotkey
+from je_auto_control.utils.exception.exception_tags import keyboard_press_key
+from je_auto_control.utils.exception.exception_tags import keyboard_release_key
+from je_auto_control.utils.exception.exception_tags import keyboard_type_key
+from je_auto_control.utils.exception.exception_tags import keyboard_write
+from je_auto_control.utils.exception.exception_tags import keyboard_write_cant_find
+from je_auto_control.utils.exception.exception_tags import table_cant_find_key
 from je_auto_control.utils.exception.exceptions import AutoControlCantFindKeyException
 from je_auto_control.utils.exception.exceptions import AutoControlKeyboardException
 from je_auto_control.utils.test_record.record_test_class import record_action_to_list
-from je_auto_control.wrapper.platform_wrapper import keyboard, special_table
+from je_auto_control.wrapper.platform_wrapper import keyboard, special_mouse_keys_table
 from je_auto_control.wrapper.platform_wrapper import keyboard_check
-from je_auto_control.wrapper.platform_wrapper import keys_table
+from je_auto_control.wrapper.platform_wrapper import keyboard_keys_table
 
 
 def get_special_table():
-    return special_table
+    return special_mouse_keys_table
 
 
-def get_keys_table():
-    return keys_table
+def get_keyboard_keys_table():
+    return keyboard_keys_table
 
 
-def press_key(keycode: [int, str], is_shift: bool = False, skip_record: bool = False) -> str:
+def press_keyboard_key(keycode: [int, str], is_shift: bool = False, skip_record: bool = False) -> str:
     """
     use to press a key still press to use release key
     or use critical exit
@@ -35,9 +35,9 @@ def press_key(keycode: [int, str], is_shift: bool = False, skip_record: bool = F
     """
     param = locals()
     try:
-        if isinstance(keycode, int):
+        if isinstance(keycode, str):
             try:
-                keycode = keys_table.get(keycode)
+                keycode = keyboard_keys_table.get(keycode)
             except AutoControlCantFindKeyException:
                 raise AutoControlCantFindKeyException(table_cant_find_key)
         try:
@@ -64,7 +64,7 @@ def press_key(keycode: [int, str], is_shift: bool = False, skip_record: bool = F
         print(repr(error), file=sys.stderr)
 
 
-def release_key(keycode: [int, str], is_shift: bool = False, skip_record: bool = False) -> str:
+def release_keyboard_key(keycode: [int, str], is_shift: bool = False, skip_record: bool = False) -> str:
     """
     use to release pressed key return keycode
     :param keycode which keycode we want to release
@@ -73,9 +73,9 @@ def release_key(keycode: [int, str], is_shift: bool = False, skip_record: bool =
     """
     param = locals()
     try:
-        if isinstance(keycode, int):
+        if isinstance(keycode, str):
             try:
-                keycode = keys_table.get(keycode)
+                keycode = keyboard_keys_table.get(keycode)
             except AutoControlCantFindKeyException:
                 raise AutoControlCantFindKeyException(table_cant_find_key)
         try:
@@ -102,7 +102,7 @@ def release_key(keycode: [int, str], is_shift: bool = False, skip_record: bool =
         print(repr(error), file=sys.stderr)
 
 
-def type_key(keycode: [int, str], is_shift: bool = False, skip_record: bool = False) -> str:
+def type_keyboard(keycode: [int, str], is_shift: bool = False, skip_record: bool = False) -> str:
     """
     press and release key return keycode
     :param keycode which keycode we want to type
@@ -112,22 +112,22 @@ def type_key(keycode: [int, str], is_shift: bool = False, skip_record: bool = Fa
     param = locals()
     try:
         try:
-            press_key(keycode, is_shift, skip_record=True)
-            release_key(keycode, is_shift, skip_record=True)
+            press_keyboard_key(keycode, is_shift, skip_record=True)
+            release_keyboard_key(keycode, is_shift, skip_record=True)
             if skip_record is False:
-                record_action_to_list("type_key", param)
+                record_action_to_list("type_keyboard", param)
             return str(keycode)
         except AutoControlKeyboardException as error:
             if skip_record is False:
-                record_action_to_list("type_key", param, repr(error))
+                record_action_to_list("type_keyboard", param, repr(error))
             raise AutoControlKeyboardException(keyboard_type_key + " " + repr(error))
         except TypeError as error:
             if skip_record is False:
-                record_action_to_list("type_key", param, repr(error))
+                record_action_to_list("type_keyboard", param, repr(error))
             raise AutoControlKeyboardException(repr(error))
     except Exception as error:
         if skip_record is False:
-            record_action_to_list("type_key", param, repr(error))
+            record_action_to_list("type_keyboard", param, repr(error))
         print(repr(error), file=sys.stderr)
 
 
@@ -141,7 +141,7 @@ def check_key_is_press(keycode: [int, str]) -> bool:
         if isinstance(keycode, int):
             get_key_code = keycode
         else:
-            get_key_code = keys_table.get(keycode)
+            get_key_code = keyboard_keys_table.get(keycode)
         record_action_to_list("check_key_is_press", param)
         return keyboard_check.check_key_is_press(keycode=get_key_code)
     except Exception as error:
@@ -153,7 +153,7 @@ def write(write_string: str, is_shift: bool = False) -> str:
     """
     use to press and release whole we get this function str
     return all press and release str
-    :param write_string while string not on write_string+1 type_key(string)
+    :param write_string while string not on write_string+1 type_keyboard(string)
     :param is_shift press shift True or False
     """
     param = locals()
@@ -162,11 +162,11 @@ def write(write_string: str, is_shift: bool = False) -> str:
             record_write_string = ""
             for single_string in write_string:
                 try:
-                    if keys_table.get(single_string) is not None:
+                    if keyboard_keys_table.get(single_string) is not None:
                         record_write_string = "".join(
                             [
                                 record_write_string,
-                                type_key(single_string, is_shift, skip_record=True)
+                                type_keyboard(single_string, is_shift, skip_record=True)
                             ]
                         )
                     else:
@@ -200,7 +200,7 @@ def hotkey(key_code_list: list, is_shift: bool = False) -> Tuple[str, str]:
                 record_hotkey_press_string = ",".join(
                     [
                         record_hotkey_press_string,
-                        press_key(key, is_shift, skip_record=True)
+                        press_keyboard_key(key, is_shift, skip_record=True)
                     ]
                 )
             key_code_list.reverse()
@@ -208,7 +208,7 @@ def hotkey(key_code_list: list, is_shift: bool = False) -> Tuple[str, str]:
                 record_hotkey_release_string = ",".join(
                     [
                         record_hotkey_release_string,
-                        release_key(key, is_shift, skip_record=True)
+                        release_keyboard_key(key, is_shift, skip_record=True)
                     ]
                 )
             record_action_to_list("hotkey", param)
